/*
 * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef STATIONS_SIMPLE_PRIVATE_H
#define STATIONS_SIMPLE_PRIVATE_H

#include <QtCore/QStringList>
#include <QtCore/QPointF>
#include <QtCore/QRectF>
#include <QtGui/QIcon>

struct StationsPluginSimplePrivate {
  QRectF rect;
  QPointF center;
  QString statusUrl;
  QString infosUrl;
  QString id;
  QString name;
  QString bikeName;
  QIcon bikeIcon;
  QString type;
};

#endif /* STATIONS_SIMPLE_PRIVATE_H */
